'The Interview' Is a Pretty Smart Movie - The Atlantic
Description: Despite the controversy, the James Franco-Seth Rogen flick is surprisingly relevant, very funny, and deserving of praise.

TheAtlantic.com
Continue ()
Advertisement

# The Atlantic

Subscribe Now
Get The Atlantic on Facebook

- ## What's Wrong With Georgia?

  By Alana Semuels

- ## Readability Is a Myth

  By Noah Berlatsky

- ## The Imitation Game: A Smart Person's Fantasy

  By Emma Green

- ## The Internet Cannot Create Social Change

  By Kentaro Toyama

Back to The Wire What is The Wire? The Wire features the latest news coverage from The Atlantic.

# The Interview Is a Pretty Smart Movie

Despite the controversy, the James Franco-Seth Rogen flick is surprisingly relevant, very funny, and deserving of praise.
Adam Chandler Dec 29 2014, 12:16 PM ET

- Share on Facebook
- Twitter
- LinkedIn
- Email
- Print
- Comments

Richard Vogel/AP

Let's assume you knew absolutely nothing about North Korea and walked into The Interview, which after a very public and protracted to-do, is now showing at a few hundred American cinemas and streaming through a number of outlets online.

Given what's been said about the movie, would you expect it to tell you about North Korea's concentration camps? Or the complexity of the dictatorship's propaganda system in which its leaders are touted as deities? Would you expect to hear (twice) that 16 million of the country's 24 million people are malnourished?

Caricature notwithstanding, The Interview has a surprisingly nuanced streak in its celluloid sea of swears and weiner jokes.

Okay, sure, The Interview might feature North Korean dictator Kim Jong Un wondering aloud about the relative "gayness" of drinking margaritas and affirming his love of Katy Perry. But caricature notwithstanding, the comedy has a surprisingly nuanced streak in its celluloid sea of swears and weiner jokes.

The Interview centers around Dave Skylark (James Franco), a fratty, self-absorbed, and disconnected celebrity TV journalist, and his producer Aaron Rapoport (Seth Rogen), who are pushed by the CIA to turn a massive scoop (an interview with reclusive North Korean dictator Kim Jong Un) into an assassination mission. Rapoport, believe it or not, laments his station as the producer of tabloid garbage and sees the Kim interview as an opportunity to perform an admirable act of journalism.

What happens next is some of what you might expect (sex, drugs, anatomy jokes) from Franco and Rogen, whose recent projects have included Pineapple Express and last year’s This Is the End. (Franco earned a Golden Globe nomination for the former and the latter still enjoys considerable sleeper praise.).

But as Skylark preens as an impressionable outsider, his gullibility and ignorance allow him to be a useful mechanism for explaining North Korea's depravity. He falls dumbly under the sway of Kim and the North Korean rhetoric machine, which paints the regime as an honorable force against the oppressive West. A major plot point turns on the dim Skylark's realization that a lush-looking grocery store he spotted earlier is a total fake. During a live-tweeting of the film on Sunday, Seth Rogen noted, "They actually have fake grocery stores in Pyongyang."

In a master stroke (spoilers ahead), the duo decides to flout the CIA's assassination order, which they determine could bring a possibly worse replacement than Kim to power. Instead, they use the live interview with Kim to destroy his credibility by stating the facts. It's not exactly Mike Wallace's showdown with Ayatollah Khomeini, but what is?

At New York, David Edelstein says that critics of the film who reduce it to a silly and sophomoric bromance, "don't know what the hell they're talking about." He adds:

> It means not just to expose Kim Jong-un as a fraud but to emasculate him, which is about the most punk thing you can do to a repressive, totalitarian, murderous, self-proclaimed god of a closed but increasingly porous state.

To that Jay McInerney adds, "Forget what you heard. #TheInterview gets my vote for best picture. Sadly I'm not a member of the Academy."

The film doesn't skate away without some problematic parts. In the end, Kim Jong Un's head does explode when a tank shell fired by Rogen and company hits the dictator's helicopter. As Uri Friedman pointed out, the decision to show Kim's death, in slow motion and while Katy Perry's "Firework" twinkles in the background, was worrisome given that "that leader's government, which presides over nuclear weapons...has described the movie as an 'act of war.'" It probably doesn't matter that Kim's death happens during a getaway battle rather than a result of an assassination.

Nevertheless, on Saturday, as if to prove the movie's point, a spokesman for the National Defense Commission, North Korea's highest governing body had this to say about The Interview, the release of which it blames on President Obama: "Obama always goes reckless in words and deeds like a monkey in a tropical forest."

After all the fuss, it's entirely understandable that many object to seeing the real, living leader of a rogue country killed onscreen. But what surprises is that The Interview also spotlights other truths that North Korea doesn't want people to hear about. Given the stakes involved, that's important too.

Presented by
Jump to Comments

- Share on Facebook
- Twitter
- LinkedIn
- Reddit
- Email
- Print
- Comments

Adam Chandler is a senior associate editor at The Atlantic, where he covers global news.

- All Posts
- Email
- Follow @allmychandler

##

More video

### The Pentagon's $1.5 Trillion Mistake

The F-35 fighter jet was supposed to do everything. Instead, it can barely do anything.

- Share on Facebook
- Twitter

More Articles

### What U.S. Intelligence Predicted the World Would Look Like in 2015

## Join the Discussion

After you comment, click Post. If you’re not already logged in you will be asked to log in or register.

blog comments powered by Disqus
Close

## Video

### The Pentagon's $1.5 Trillion Mistake

The F-35 fighter jet was supposed to do everything. Instead, it can barely do anything.

## Video

### How to Cook Spaghetti Squash (and Why)

Cooking for yourself is one of the surest ways to eat well.

## Video

### Before Tinder, a Tree

Looking for your soulmate? Write a letter to the "Bridegroom's Oak" in Germany.

## Video

### Where High Tech Meets the 1950s

Why did Green Bank, West Virginia, ban wireless signals? For science.

## Video

### Would You Live in a Treehouse?

A treehouse can be an ideal office space, vacation rental, and way of reconnecting with your youth.

## More in Entertainment

- ### The Imitation Game: A Smart Person's Fantasy

  Emma Green

- ### Readability Is a Myth

  Noah Berlatsky

- ### A Design Magazine That's More Than Just Pretty

  Steven Heller

## In Focus

### 2015: Ringing in the New Year

## Just In

- ### Why Would Anybody Adopt the Euro in 2015?

  Adam Chandler

- ### In Partial Defense of Lee Greenwood's Grammatically Challenged 'God Bless the U.S.A.'

  Jeffrey Goldberg

- ### Human Traffickers Are Abandoning Boats Full of Migrants

  Adam Chandler

## Most Popular

1
  The Tragedy of the American Military
2
  What's Wrong With Georgia?
3
  The Death of the Artist—and the Birth of the Creative Entrepreneur
4
  Readability Is a Myth
5
  All the Single Ladies
6
  The Future of Getting Arrested
7
  What U.S. Intelligence Predicted the World Would Look Like in 2015
8
  The Imitation Game: A Smart Person's Fantasy
9
  A Hacker's Hit List of American Infrastructure
10
  The Benefits of Fewer NYPD Arrests

Powered by the Parse.ly Publisher Platform (P3).